Blocked class

Inheritance
Implementers

Constructors

Blocked({InstallApp? installApp, HomeMenuModel? homeMenu, DrawerModel? drawer, DrawerModel? endDrawer})

Properties

drawer → DrawerModel?
finalinherited
endDrawer → DrawerModel?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
homeMenu → HomeMenuModel?
finalinherited
installApp → InstallApp?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → Future<PageModel>
toString() → String
A string representation of this object.
inherited
uploadBlockedImage() → Future<PlatformMediumModel>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

blockedIdentifier ↔ String
getter/setter pair
identifier ↔ String
getter/setter pair