NotificationDashboard class

Inheritance
Implementers

Constructors

NotificationDashboard(InstallApp? installApp)

Properties

hashCode → int
The hash code for this object.
no setterinherited
installApp → InstallApp?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → Future<DialogModel>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

identifier ↔ String
getter/setter pair

Static Methods

action(AppModel app) → OpenDialog